==> orionis-0.476.0.tar.gz: orionis-0.476.0/orionis/foundation/providers/executor_provider.py <==
from orionis.console.output.contracts.executor import IExecutor
from orionis.console.output.executor import Executor
from orionis.container.providers.service_provider import ServiceProvider

class ConsoleExecuteProvider(ServiceProvider):
    """
    Console executor service provider for dependency injection container registration.

    This service provider is responsible for registering and configuring console executor
    services within the application's dependency injection container. It binds the
    IExecutor interface to its concrete Executor implementation, enabling standardized
    console operations throughout the application including command execution, output
    formatting, and process management.

    The provider follows the standard service provider lifecycle pattern, implementing
    both registration and boot phases to ensure proper service initialization and
    configuration within the application container.

    Attributes
    ----------
    app : Container
        The application's dependency injection container instance used for service
        registration and binding management.

    Methods
    -------
    register() -> None
        Registers the console executor service binding in the container.
    boot() -> None
        Performs post-registration initialization and configuration tasks.

    Notes
    -----
    This provider registers services as transient bindings to ensure isolated
    execution contexts for each console operation request.
    """

    def register(self) -> None:
        """
        Register the console executor service in the application container.

        This method binds the IExecutor interface to its concrete Executor implementation
        as a transient service. The transient binding ensures that a new instance of
        the Executor is created each time it is requested from the container, providing
        isolated execution contexts for console operations.

        The service is registered with the alias "x-orionis.console.output.executor" to
        enable easy retrieval and identification within the dependency injection container.

        Returns
        -------
        None
            This method does not return any value. It performs the side effect of
            registering the executor service binding in the application container.
        """

        self.app.transient(IExecutor, Executor, alias="x-orionis.console.output.executor")

    def boot(self) -> None:
        """
        Perform post-registration initialization for the console executor provider.

        This method is called after the service registration phase and provides
        an opportunity to perform additional setup, configuration, or initialization
        tasks that depend on the registered services. It follows the service provider
        lifecycle pattern where registration occurs first, followed by booting.

        Currently, this implementation serves as a placeholder and does not perform
        any specific initialization tasks. Subclasses or future implementations may
        override this method to add custom boot logic such as service validation,
        configuration setup, or dependent service initialization.

        Returns
        -------
        None
            This method does not return any value. It performs initialization
            side effects only.
        """

        pass

==> orionis-0.577.0.tar.gz: orionis-0.577.0/orionis/foundation/providers/executor_provider.py <==
from orionis.console.contracts.executor import IExecutor
from orionis.console.output.executor import Executor
from orionis.container.providers.service_provider import ServiceProvider

class ConsoleExecuteProvider(ServiceProvider):
    """
    Console executor service provider for dependency injection container registration.

    This service provider is responsible for registering and configuring console executor
    services within the application's dependency injection container. It binds the
    IExecutor interface to its concrete Executor implementation, enabling standardized
    console operations throughout the application including command execution, output
    formatting, and process management.

    The provider follows the standard service provider lifecycle pattern, implementing
    both registration and boot phases to ensure proper service initialization and
    configuration within the application container.

    Attributes
    ----------
    app : Container
        The application's dependency injection container instance used for service
        registration and binding management.

    Methods
    -------
    register() -> None
        Registers the console executor service binding in the container.
    boot() -> None
        Performs post-registration initialization and configuration tasks.

    Notes
    -----
    This provider registers services as transient bindings to ensure isolated
    execution contexts for each console operation request.
    """

    def register(self) -> None:
        """
        Register the console executor service in the application container.

        This method binds the IExecutor interface to its concrete Executor implementation
        as a transient service. The transient binding ensures that a new instance of
        the Executor is created each time it is requested from the container, providing
        isolated execution contexts for console operations.

        The service is registered with the alias "x-orionis.console.output.executor" to
        enable easy retrieval and identification within the dependency injection container.

        Returns
        -------
        None
            This method does not return any value. It performs the side effect of
            registering the executor service binding in the application container.
        """

        self.app.transient(IExecutor, Executor, alias="x-orionis.console.output.executor")

    def boot(self) -> None:
        """
        Perform post-registration initialization for the console executor provider.

        This method is called after the service registration phase and provides
        an opportunity to perform additional setup, configuration, or initialization
        tasks that depend on the registered services. It follows the service provider
        lifecycle pattern where registration occurs first, followed by booting.

        Currently, this implementation serves as a placeholder and does not perform
        any specific initialization tasks. Subclasses or future implementations may
        override this method to add custom boot logic such as service validation,
        configuration setup, or dependent service initialization.

        Returns
        -------
        None
            This method does not return any value. It performs initialization
            side effects only.
        """

        pass
